@@ -119,8 +119,29 @@ chmod -R 777 /usr/local/goip
 
 [ -f "/etc/conf.d/local.start" ] && local="/etc/conf.d/local.start";
 [ -f "/etc/rc.d/rc.local" ] && local="/etc/rc.d/rc.local"
-[ -f "/etc/rc.local" ] && local="/etc/rc.local"
 
+if [ -f "/etc/rc.local" ];then
+    local="/etc/rc.local" && chmod +x /etc/rc.local
+else
+    systemd -h &> /dev/null
+    if [ $? -eq 0 ];then
+        touch /etc/rc.local && echo "#!/bin/sh" > /etc/rc.local && chmod +x /etc/rc.local && local="/etc/rc.local"
+        rctmp="/tmp/rc.local.dbltek.service"
+        echo "[Unit]" > $rctmp
+	echo "Description=/etc/rc.local Compatibility" >> $rctmp
+	echo "Documentation=man:systemd-rc-local-generator(8)" >> $rctmp
+	echo "ConditionFileIsExecutable=/etc/rc.local" >> $rctmp
+	echo "After=network.target" >> $rctmp
+	echo "[Service]" >> $rctmp
+	echo "Type=forking" >> $rctmp
+	echo "ExecStart=/etc/rc.local start" >> $rctmp
+	echo "TimeoutSec=0" >> $rctmp
+	echo "RemainAfterExit=yes" >> $rctmp
+	echo "GuessMainPID=no" >> $rctmp
+        [ -d "/lib/systemd/system/" ] && cp $rctmp  /lib/systemd/system/
+        [ -d "/etc/systemd/system/" ] && ln -s /lib/systemd/system/rc.local.dbltek.service /etc/systemd/system/rc.local.dbltek.service
+    fi
+fi
 
 rclocaltmp=`mktemp /tmp/rclocal.XXXXXXXXXX`
 
